e4clim: Energy for CLimate Integrated Model
============================================

The Energy for CLimate Integrated Model.

See the [e4clim documentation](https://alexis.tantet.pages.in2p3.fr/e4clim/) for more details.
